
#include "global.h"

#ifdef SOLARIS
#include <sys/fcntl.h>
#endif

extern int rndint;


  extern int rightborder,LASTPLAYER,longrangewidth,longrangeheight;
  extern int SCROLL,NUMPLANETS;
  extern VirtualType virtual;
  extern PhysicalType physical[MAXPLAYERS+1];
  extern DeviceType device[MAXPLAYERS+1];
  extern ShipType ship[MAXPLAYERS+1];
  extern Objtype obj[LASTOBJ+1];

/*****************************************************************************/
/* This function will open the passed file name,
   read the contents of the file into the passed buffer and close 
   the file */

void readfile(filename,buffer,buffersize) 
char *filename,*buffer;
int buffersize;
{
 int fd;

   printf("opening file %s\n",filename);  
    fd = open(filename,0,O_RDONLY);
   
    if (fd < 0){
        printf("error opening file %s make sure it is in your current directory\n",filename);   
        exit(1);
        return;
     }
   read(fd,buffer,buffersize); 
   close(fd);
}
/*****************************************************************************/
/* This function will read in the data file for the simualtion parameters
   and call the get ship function for all of the ships defined in the
   simulation parameters
*/
void getdefaults() {
  int fd,i;
  int bufsize = 200;
  float scaley,scalex;
  char *buffer= (char *)malloc(bufsize);


  fd = open("sw.dat",0,O_RDONLY);
  if (fd < 0) {

     printf("sw.dat not found, make sure sw.dat is in your current directory \n");

     exit(1);
     return;
   }
  read(fd,buffer,bufsize); 
/*                        x1 y1 x2 y2 w  h  x  y  w  h  w  h  */            
  sscanf(buffer,"%i %i %i %i %i %i %i %i %i %i %i %i %i %i %i",
               &LASTPLAYER,&SCROLL,&NUMPLANETS,
               &virtual.x1 ,&virtual.y1 ,&virtual.x2 ,
               &virtual.y2 ,&virtual.width ,&virtual.height,
               &physical[1].x ,&physical[1].y ,&physical[1].width ,
               &physical[1].height , 
               &device[1].width,&device[1].height);

/*
   printf(        "%i %i %i %i %i %i %i %i %i %i %i %i %i %i %f %f",
          LASTPLAYER,SCROLL,
          virtual.x1 ,virtual.y1 ,virtual.x2 ,
          virtual.y2 ,virtual.width ,virtual.height,
          physical[1].x ,physical[1].y ,physical[1].width ,physical[1].height , 
          device[1].width,device[1].height,scalex,scaley);
*/
  close(fd);
  device[1].scalex = 0.5;
  device[1].scaley = 0.5;

/* copy  physical and device to other players */
  for ( i = 2; i <= MAXPLAYERS; i++) { 
    physical[i] = physical[1];
    device[i] = device[1];
  }
  for ( i = FIRSTPLAYER; i <= LASTPLAYER; i++ ){
    getship(i);
  }

  
}
/*****************************************************************************/
/* This function will return the ship that is closest to the passed player
   If there are not other ships alive in the simulation NOSHIP will be returned
 */

int FindClosestShip(player) 
     int player;
{
   double *dist,mindistance = 10000000.0;
   int closestship = NOSHIP;
   int i;

   for (i = FIRSTPLAYER; i <= LASTPLAYER; i++){
     if (i != player && obj[i].alive) {
       dist = (double*) distance(player,i);
#ifdef DEBUG

   printf("distance betwwen player %i and %i is %f\n",
          player,i,(float)dist);
#endif         
       if (*dist < mindistance) {
         mindistance = *dist;
         closestship = i;

       }
     }
   }
#ifdef DEBUG
   printf("Closet ship to player %i is %i\n",player,closestship);
#endif
   
   return closestship;
}

/*****************************************************************************/
/* This function will create an enemy ship that will clone the
   ship used by the passed player. It is controlled by the simulation,
   not by any users of the simulation*/

makeenemy(player) /* Start an enemy ship  */
     int player;
{ extern Objtype obj[LASTOBJ+1]; 
  extern int  rndint;
  unsigned char c;

/* clone a player ship */
  ship[ENEMY] = ship[player];
  obj[ENEMY].alive = 1;
  obj[ENEMY].x = 0;
  obj[ENEMY].y = (double) virtual.height/4;
  c = rand(rndint); 
  obj[ENEMY].y += (double) c;
  obj[ENEMY].xvel = 0.1;
  obj[ENEMY].yvel = 0;

}
/*****************************************************************************/

int nextast() /* Find next unused asteroid object */
{ extern Objtype obj[LASTOBJ+1];
  int i;
  for (i = AST; obj[i].alive && i < LASTOBJ; i++); /* guaranteed to find one */
  if (i >= LASTOBJ) {
    printf("Not enough space in object table\n");
    return LASTOBJ;
  }
  return i;
}

/*****************************************************************************/
/* Returns a random integer between first and last */

int rnd ( first, last ) 
int first, last;
{
  int i;
  i = last - first;
  i = (int)((double) i * (double)rand(rndint)/(double)INT_MAX);
/*DD  printf("i %i first %i last %i\n",i + first,first,last);
*/
  return i + first;
}
/* This function will control the systems of the computer controlled
   ships.  Currenly there is only one computer controlled ship that
   changes it's x and y velocity randomly and always fires at the direction
   of the nearest player
*/

/*****************************************************************************/
void AdjustComputerControlledShips ()

{
  int c,s;
  int player;
  static int enemymovecount = 10;
  static int enemyfirecount = 10;
  
  double xvel,yvel;
  
  if (!obj[ENEMY].alive) {
    c = rnd(1,600);
/* this was c > 598 */
    if (c > 598) {
      
      makeenemy(1);
    }   
  }
  else {
    enemymovecount--;
    if (!enemymovecount) {
      obj[ENEMY].yvel = rnd(1,10) - 5;
      obj[ENEMY].xvel = rnd(1,10) - 5;
      enemymovecount = 80;  
      
    }         
    
    enemyfirecount--;
    if (!enemyfirecount) {
      enemyfirecount = ship[ENEMY].reloadtime * 2;
      player = FindClosestShip(ENEMY);
      /*       turretfire(ENEMY,obj[player].x,obj[player].y); */
      
      obj[ENEMY].rot = atan2((double)(obj[player].y - obj[ENEMY].y ), 
                             (double)(obj[player].x -obj[ENEMY].x ));;
      xvel = obj[ENEMY].xvel;
      yvel = obj[ENEMY].yvel;
      obj[ENEMY].xvel = 0.0;
      obj[ENEMY].yvel = 0.0;
      
      fire(ENEMY);
      obj[ENEMY].xvel = xvel;
      obj[ENEMY].yvel = yvel;
      
    }
    
  }
}





